#ifndef _KINSTANCE_H
#define _KINSTANCE_H

class KStandardDirs;
class KAboutData;
class KConfig;
class KIconLoader;
class KCharsets;
class QFont;

#include <qstring.h>


/**
 * Access to KDE global objects for use in shared libraries.
 *
 * @author Torben Weis
 * @version $Id: kinstance.h,v 1.13 2000/01/09 22:59:21 waba Exp $
 */
class KInstance
{
 public:
    /**
     *  Constructor
     *  @param instanceName the name of the instance
     **/
    KInstance( const QCString& instanceName) ;

    /**
     *  Constructor
     *  @param aboutData data about this instance (see @ref KAboutData)
     **/
    KInstance( const KAboutData * aboutData = 0L );

    /**
     * Destructor.
     */
    virtual ~KInstance();
    
    /**
     *  Retrieve the application standard dirs object.
     */
    KStandardDirs	*dirs() const;
    
    /**
     *  Retrieve the general config object.
     */
    KConfig *config() const;
    
    /**
     *  Retrieve an iconloader object.
     */
    KIconLoader	*iconLoader() const;
    
    KCharsets	     *charsets() const;
    
    /**
     *  @return the about data of this instance
     *  Warning, can be 0L
     */
    const KAboutData *aboutData() const;

    /**
     * @return the instance name
     */
    QCString          instanceName() const;

protected:
    /**
     *  Copy Constructor is not allowed
     */
    KInstance( const KInstance& );
    
public:
    mutable KStandardDirs	*_dirs;
    
    mutable KConfig		*_config;
    mutable KIconLoader	        *_iconLoader;

    QCString                     _name;
    const KAboutData            *_aboutData;
};

#endif 

